==> open-xchange-guard_2.10.6.orig.tar.bz2: open-xchange-guard-2.10.6/com.openexchange.guard/src/com/openexchange/guard/servlets/supportApi/DeleteUserAction.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.guard.servlets.supportApi;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.openexchange.guard.common.servlets.utils.ServletUtils;
import com.openexchange.guard.inputvalidation.EmailValidator;
import com.openexchange.guard.servlets.GuardServletAction;
import com.openexchange.guard.servlets.authentication.GuardUserSession;
import com.openexchange.guard.support.SupportService;
import com.openexchange.guard.support.SupportServiceImpl;

/**
 * Deletes all Guard key for a certain user (key backups are created)
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.0
 */
public class DeleteUserAction extends GuardServletAction {

    private static final String PARAM_NAME_EMAIL = "email";
    private static final String PARAM_NAME_USERID = "user_id";
    private static final String PARAM_NAME_CONTEXTID = "cid";

    SupportService supportService;

    public DeleteUserAction() {
        supportService = new SupportServiceImpl();
    }

    @Override
    public void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {

        //Check if parameter "email" was provided
        String email = ServletUtils.getStringParameter(request, PARAM_NAME_EMAIL);
        if (email != null && !email.isEmpty()) {
            email = new EmailValidator().assertInput(email, PARAM_NAME_EMAIL);
            supportService.deleteUser(email);
        }
        else {
            //Check for parameters "userid" and "contextid" were provided
            int contextId = ServletUtils.getIntParameter(request, PARAM_NAME_CONTEXTID, true);
            int userId = ServletUtils.getIntParameter(request, PARAM_NAME_USERID, true);
            supportService.deleteUser(contextId, userId);
        }
        ServletUtils.sendOK(response, "text/plain", "OK");
    }
}

==> open-xchange-guard_2.10.7.orig.tar.bz2: open-xchange-guard-2.10.7/com.openexchange.guard/src/com/openexchange/guard/servlets/supportApi/DeleteUserAction.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.guard.servlets.supportApi;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.openexchange.guard.common.servlets.utils.ServletUtils;
import com.openexchange.guard.common.session.GuardUserSession;
import com.openexchange.guard.inputvalidation.EmailValidator;
import com.openexchange.guard.servlets.GuardServletAction;
import com.openexchange.guard.support.SupportService;
import com.openexchange.guard.support.SupportServiceImpl;

/**
 * Deletes all Guard key for a certain user (key backups are created)
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.0
 */
public class DeleteUserAction extends GuardServletAction {

    private static final String PARAM_NAME_EMAIL = "email";
    private static final String PARAM_NAME_USERID = "user_id";
    private static final String PARAM_NAME_CONTEXTID = "cid";

    SupportService supportService;

    public DeleteUserAction() {
        supportService = new SupportServiceImpl();
    }

    @Override
    public void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {

        //Check if parameter "email" was provided
        String email = ServletUtils.getStringParameter(request, PARAM_NAME_EMAIL);
        if (email != null && !email.isEmpty()) {
            email = new EmailValidator().assertInput(email, PARAM_NAME_EMAIL);
            supportService.deleteUser(email);
        }
        else {
            //Check for parameters "userid" and "contextid" were provided
            int contextId = ServletUtils.getIntParameter(request, PARAM_NAME_CONTEXTID, true);
            int userId = ServletUtils.getIntParameter(request, PARAM_NAME_USERID, true);
            supportService.deleteUser(contextId, userId);
        }
        ServletUtils.sendOK(response, "text/plain", "OK");
    }
}
